datastructuretools.ContextMap
=============================

.. abjad-lineage:: abjad.tools.datastructuretools.ContextMap.ContextMap

.. autoclass:: abjad.tools.datastructuretools.ContextMap.ContextMap

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.ContextMap.ContextMap.copy
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.score_template
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.settings
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.update
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.__eq__
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.__format__
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.__getitem__
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.__hash__
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.__ne__
      ~abjad.tools.datastructuretools.ContextMap.ContextMap.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.ContextMap.ContextMap.score_template
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.ContextMap.ContextMap.settings
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.ContextMap.ContextMap.copy
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ContextMap.ContextMap.update
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.ContextMap.ContextMap.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ContextMap.ContextMap.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ContextMap.ContextMap.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ContextMap.ContextMap.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ContextMap.ContextMap.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ContextMap.ContextMap.__repr__
   :noindex:
